==> liggghts_3.5.0+repack1.orig.tar.xz: LIGGGHTS-PUBLIC-3.5.0/src/properties.h <==
/* ----------------------------------------------------------------------
    This is the

    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®

    DEM simulation engine, released by
    DCS Computing Gmbh, Linz, Austria
    http://www.dcs-computing.com, office@dcs-computing.com

    LIGGGHTS® is part of CFDEM®project:
    http://www.liggghts.com | http://www.cfdem.com

    Core developer and main author:
    Christoph Kloss, christoph.kloss@dcs-computing.com

    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
    License, version 2 or later. It is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
    received a copy of the GNU General Public License along with LIGGGHTS®.
    If not, see http://www.gnu.org/licenses . See also top-level README
    and LICENSE files.

    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
    the producer of the LIGGGHTS® software and the CFDEM®coupling software
    See http://www.cfdem.com/terms-trademark-policy for details.

-------------------------------------------------------------------------
    Contributing author and copyright for this file:
    (if no contributing author is listed, this file has been contributed
    by the core developer)

    Copyright 2015-     DCS Computing GmbH, Linz
------------------------------------------------------------------------- */

#ifndef LMP_PROPERTIES_H
#define LMP_PROPERTIES_H

#include "lammps.h"
#include "pointers.h"

namespace LAMMPS_NS {

class Properties: protected Pointers
{
 public:

  Properties(LAMMPS *lmp);
  ~Properties();

  int max_type();
  double min_radius();
  double max_radius();
  void* find_property(const char *name, const char *type, int &len1, int &len2);
  inline class Multisphere *ms_data() { return ms_data_;}

  bool allow_soft_particles()
  { return allow_soft_particles_; }

  void do_allow_soft_particles()
  { allow_soft_particles_ = true; }
  void do_not_allow_soft_particles()
  { allow_soft_particles_ = false; }

 private:

  // multisphere
  class FixMultisphere *ms_;
  class Multisphere *ms_data_;

  int mintype_,maxtype_;

  bool allow_soft_particles_;
}; //end class

}

#endif

==> liggghts_3.8.0+repack1.orig.tar.xz: LIGGGHTS-PUBLIC-3.8.0/src/properties.h <==
/* ----------------------------------------------------------------------
    This is the

    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®

    DEM simulation engine, released by
    DCS Computing Gmbh, Linz, Austria
    http://www.dcs-computing.com, office@dcs-computing.com

    LIGGGHTS® is part of CFDEM®project:
    http://www.liggghts.com | http://www.cfdem.com

    Core developer and main author:
    Christoph Kloss, christoph.kloss@dcs-computing.com

    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
    License, version 2 or later. It is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
    received a copy of the GNU General Public License along with LIGGGHTS®.
    If not, see http://www.gnu.org/licenses . See also top-level README
    and LICENSE files.

    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
    the producer of the LIGGGHTS® software and the CFDEM®coupling software
    See http://www.cfdem.com/terms-trademark-policy for details.

-------------------------------------------------------------------------
    Contributing author and copyright for this file:
    (if no contributing author is listed, this file has been contributed
    by the core developer)

    Copyright 2015-     DCS Computing GmbH, Linz
------------------------------------------------------------------------- */

#ifndef LMP_PROPERTIES_H
#define LMP_PROPERTIES_H

#include "lammps.h"
#include "pointers.h"

namespace LAMMPS_NS {

class Properties: protected Pointers
{
 public:

  Properties(LAMMPS *lmp);
  ~Properties();

  int max_type();
  double min_radius();
  double max_radius();
  void* find_property(const char *name, const char *type, int &len1, int &len2);
  inline class Multisphere *ms_data() { return ms_data_;}

  bool allow_soft_particles()
  { return allow_soft_particles_; }

  void do_allow_soft_particles()
  { allow_soft_particles_ = true; }
  void do_not_allow_soft_particles()
  { allow_soft_particles_ = false; }

  bool allow_hard_particles()
  { return allow_hard_particles_; }

  void do_allow_hard_particles()
  { allow_hard_particles_ = true; }
  void do_not_allow_hard_particles()
  { allow_hard_particles_ = false; }

 private:

  // multisphere
  class FixMultisphere *ms_;
  class Multisphere *ms_data_;

  int mintype_,maxtype_;

  bool allow_soft_particles_;
  bool allow_hard_particles_;
}; //end class

}

#endif
